summaryrefslogtreecommitdiffstats
path: root/qtinterface/tqt4/Qt/qbytearray.h
diff options
context:
space:
mode:
Diffstat (limited to 'qtinterface/tqt4/Qt/qbytearray.h')
-rw-r--r--qtinterface/tqt4/Qt/qbytearray.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/qtinterface/tqt4/Qt/qbytearray.h b/qtinterface/tqt4/Qt/qbytearray.h
index 9ee2be3..754c891 100644
--- a/qtinterface/tqt4/Qt/qbytearray.h
+++ b/qtinterface/tqt4/Qt/qbytearray.h
@@ -62,7 +62,7 @@ QT_MODULE(Core)
Safe and portable C string functions; extensions to standard string.h
*****************************************************************************/
-Q_CORE_EXPORT char *qstrdup(const char *);
+Q_CORE_EXPORT char *tqstrdup(const char *);
inline uint qstrlen(const char *str)
{ return str ? uint(strlen(str)) : 0; }
@@ -78,7 +78,7 @@ inline uint qstrnlen(const char *str, uint maxlen)
}
Q_CORE_EXPORT char *qstrcpy(char *dst, const char *src);
-Q_CORE_EXPORT char *qstrncpy(char *dst, const char *src, uint len);
+Q_CORE_EXPORT char *tqstrncpy(char *dst, const char *src, uint len);
Q_CORE_EXPORT int qstrcmp(const char *str1, const char *str2);
Q_CORE_EXPORT int qstrcmp(const QByteArray &str1, const QByteArray &str2);
@@ -91,15 +91,15 @@ inline int qstrncmp(const char *str1, const char *str2, uint len)
return (str1 && str2) ? strncmp(str1, str2, len)
: (str1 ? 1 : (str2 ? -1 : 0));
}
-Q_CORE_EXPORT int qstricmp(const char *, const char *);
-Q_CORE_EXPORT int qstrnicmp(const char *, const char *, uint len);
+Q_CORE_EXPORT int tqstricmp(const char *, const char *);
+Q_CORE_EXPORT int tqstrnicmp(const char *, const char *, uint len);
// implemented in qvsnprintf.cpp
Q_CORE_EXPORT int qvsnprintf(char *str, size_t n, const char *fmt, va_list ap);
Q_CORE_EXPORT int qsnprintf(char *str, size_t n, const char *fmt, ...);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void *qmemmove(void *dst, const void *src, uint len)
+inline QT3_SUPPORT void *tqmemmove(void *dst, const void *src, uint len)
{ return memmove(dst, src, len); }
inline QT3_SUPPORT uint cstrlen(const char *str)
{ return uint(strlen(str)); }
@@ -111,9 +111,9 @@ inline QT3_SUPPORT int cstrncmp(const char *str1, const char *str2, uint len)
{ return strncmp(str1,str2,len); }
#endif
-// qChecksum: Internet checksum
+// tqChecksum: Internet checksum
-Q_CORE_EXPORT quint16 qChecksum(const char *s, uint len);
+Q_CORE_EXPORT quint16 tqChecksum(const char *s, uint len);
class QByteRef;
class QString;
@@ -583,10 +583,10 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QByteArray &);
#endif
#ifndef QT_NO_COMPRESS
-Q_CORE_EXPORT QByteArray qCompress(const uchar* data, int nbytes, int compressionLevel = -1);
+Q_CORE_EXPORT QByteArray tqCompress(const uchar* data, int nbytes, int compressionLevel = -1);
Q_CORE_EXPORT QByteArray qUncompress(const uchar* data, int nbytes);
-inline QByteArray qCompress(const QByteArray& data, int compressionLevel = -1)
-{ return qCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
+inline QByteArray tqCompress(const QByteArray& data, int compressionLevel = -1)
+{ return tqCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
inline QByteArray qUncompress(const QByteArray& data)
{ return qUncompress(reinterpret_cast<const uchar*>(data.constData()), data.size()); }
#endif